<?php

/**
 * Initialize theme settings
 */
if (is_null(theme_get_setting('rebuild_registry'))) {

// Auto-rebuild the theme registry during theme development.
  if(theme_get_setting('rebuild_registry')) {
    drupal_set_message(t('The theme registry has been rebuilt. <a href="!link">Turn off</a> this feature on production websites.', array('!link' => url('admin/build/themes/settings/' . $GLOBALS['theme']))), 'warning');
  }

  global $theme_key;
// Get node types
  $node_types = node_get_types('names');

/**
 * The default values for the theme variables. Make sure $defaults exactly
 * matches the $defaults in the theme-settings.php file.
 */
  $defaults = array(
    'fix_css_limit'     => 0,
    'devlink'           => 0,
    'rebuild_registry'  => 0,
  );

// Make the default content-type settings the same as the default theme settings,
// so we can tell if content-type-specific settings have been altered.
  $defaults = array_merge($defaults, theme_get_settings());

// Get default theme settings.
  $settings = theme_get_settings($theme_key);

// Don't save the toggle_node_info_ variables
  if (module_exists('node')) {
    foreach (node_get_types() as $type => $name) {
      unset($settings['toggle_node_info_'. $type]);
    }
  }

// Save default theme settings
  variable_set(
    str_replace('/', '_', 'theme_'. $theme_key .'_settings'),
    array_merge($defaults, $settings)
  );

// Force refresh of Drupal internals
  theme_get_setting('', TRUE);
}

// add jquery.pngFix.js file
drupal_add_js(drupal_get_path('theme', 'salamanderskins') . '/js/jquery.pngFix.js', 'theme');
drupal_add_js(drupal_get_path('theme', 'salamanderskins') . '/js/suckerfish.js', 'theme');



function salamanderskins_preprocess_page(&$vars) {
  global $language;
// Remove the duplicate meta content-type tag, a bug in Drupal 6
  $vars['head'] = preg_replace('/<meta http-equiv=\"Content-Type\"[^>]*>/', '', $vars['head']);


// Use grouped import technique for more than 30 un-aggregated stylesheets (css limit fix for IE)
  $css = drupal_add_css();
  if (isset($_SERVER['HTTP_USER_AGENT']) && (strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') !== false)) {
    if (theme_get_setting('fix_css_limit') && !variable_get('preprocess_css', FALSE) && salamanderskins_css_count($css) > 26) {
      $styles = '';
      $suffix = "\n".'</style>'."\n";
      foreach ($css as $media => $types) {
        $prefix = '<style type="text/css" media="'. $media .'">'."\n";
        $imports = array();
        foreach ($types as $files) {
          foreach ($files as $file => $preprocess) {
            $imports[] = '@import "'. base_path() . $file .'";';
            if (count($imports) == 30) {
              $styles .= $prefix . implode("\n", $imports) . $suffix;
              $imports = array();
            }
          }
        }
        $styles .= (count($imports) > 0) ? ($prefix . implode("\n", $imports) . $suffix) : '';
      }
      $vars['styles'] = $styles;
    }
    else {
      $vars['styles'] = drupal_get_css();                                   // Use normal link technique
    }
  }

$devlink = theme_get_setting('devlink');
  if ($devlink == '0'){ 
	  $dvlk = 'byn';
  }
  if ($devlink == '1'){ 
	  $dvlk = 'byy';
  }
  $momo = array();
  $momo[] = ($vars['node']->type) ? $vars['node']->type .' | ' : '';
  $momo = array_filter($momo);
  $vars['momo'] = implode(' ', $momo);
  $vars['closure'] .= ($vars['is_front']) ? '<div class="'.$dvlk.'"><a href="http://www.eucopyright.com">EU Copyright</a></div>' : '<div class="'.$dvlk.'"><a href="http://www.eucopyright.com">Copyright'.$vars['momo'].'</a></div>';
}


/* Set default form file input size */
function salamanderskins_file($element) {
  $element['#size'] = ($element['#size'] > 40) ? 40 : $element['#size'];
  return theme_file($element);
}

/* Count the total number of CSS files in $vars['css'] */
function salamanderskins_css_count($array) {
  $count = 0;
  foreach ($array as $item) {
    $count = (is_array($item)) ? $count + salamanderskins_css_count($item) : $count + 1;
  }
  return $count;
}

/**
 * Creates a link with prefix and suffix text
 *
 * @param $prefix
 *   The text to prefix the link.
 * @param $suffix
 *   The text to suffix the link.
 * @param $text
 *   The text to be enclosed with the anchor tag.
 * @param $path
 *   The Drupal path being linked to, such as "admin/content/node". Can be an external
 *   or internal URL.
 *     - If you provide the full URL, it will be considered an
 *   external URL.
 *     - If you provide only the path (e.g. "admin/content/node"), it is considered an
 *   internal link. In this case, it must be a system URL as the url() function
 *   will generate the alias.
 * @param $options
 *   An associative array that contains the following other arrays and values
 *     @param $attributes
 *       An associative array of HTML attributes to apply to the anchor tag.
 *     @param $query
 *       A query string to append to the link.
 *     @param $fragment
 *       A fragment identifier (named anchor) to append to the link.
 *     @param $absolute
 *       Whether to force the output to be an absolute link (beginning with http:).
 *       Useful for links that will be displayed outside the site, such as in an RSS
 *       feed.
 *     @param $html
 *       Whether the title is HTML or not (plain text)
 * @return
 *   an HTML string containing a link to the given path.
 */
function salamanderskins_themesettings_link($prefix, $suffix, $text, $path, $options) {
  return $prefix . (($text) ? l($text, $path, $options) : '') . $suffix;
}


/* Breadcrumb override */
function salamanderskins_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
    $breadcrumb[] = drupal_get_title();  // full breadcrumb (  = › ,  = &#187; &raquo;)
    return '<div class="breadcrumb">'. implode(' &raquo; ', $breadcrumb) .'</div>';
  }
}


/**
 * Converts a string to a suitable html ID attribute.
 *
 * http://www.w3.org/TR/html4/struct/global.html#h-7.5.2 specifies what makes a
 * valid ID attribute in HTML. This function:
 *
 * - Ensure an ID starts with an alpha character by optionally adding an 'id'.
 * - Replaces any character except A-Z, numbers, and underscores with dashes.
 * - Converts entire string to lowercase.
 *
 * @param $string
 *   The string
 * @return
 *   The converted string
 */
function id_safe($string) {
  // Replace with dashes anything that isn't A-Z, numbers, dashes, or underscores.
  $string = strtolower(preg_replace('/[^a-zA-Z0-9_-]+/', '-', $string));
  // If the first character is not a-z, add 'n' in front.
  if (!ctype_lower($string{0})) { // Don't use ctype_alpha since its locale aware.
    $string = 'id' . $string;
  }
  return $string;
}



/* Quick fix for the validation error: 'ID "edit-submit" already defined' */
$elementCountForHack = 0;
function salamanderskins_submit($element) {
	global $elementCountForHack;
	return str_replace('edit-submit', 'edit-submit-' . ++$elementCountForHack, theme('button', $element));
}

