<?php

/**
 * Theme setting defaults
 */
function salamanderskins_default_theme_settings() {
  $defaults = array(
    'fix_css_limit'     => 0,
    'devlink'           => 0,
    'rebuild_registry'  => 0,
  );

// Add site-wide theme settings
  $defaults = array_merge($defaults, theme_get_settings());

  return $defaults;
}


/**
 * Theme setting initialization
 * if updated, unsaved, or registry rebuild mode
 */
function salamanderskins_initialize_theme_settings($theme_name) {
  $theme_settings = theme_get_settings($theme_name);
  if (is_null($theme_settings['fix_css_limit']) || $theme_settings['rebuild_registry'] == 1) {
// Rebuild theme registry & notify user
    if($theme_settings['rebuild_registry'] == 1) {
      drupal_rebuild_theme_registry();
      drupal_set_message(t('Theme registry rebuild completed. <a href="!link">Turn off</a> this feature for production websites.', array('!link' => url('admin/build/themes/settings/' . $GLOBALS['theme']))), 'warning');
    }
  
// Retrieve saved or site-wide theme settings
    $theme_setting_name = str_replace('/', '_', 'theme_'. $theme_name .'_settings');
    $settings = (variable_get($theme_setting_name, FALSE)) ? theme_get_settings($theme_name) : theme_get_settings();
  
// Skip toggle_node_info_ settings
    if (module_exists('node')) {
      foreach (node_get_types() as $type => $name) {
        unset($settings['toggle_node_info_'. $type]);
      }
    }
  
// Retrieve default theme settings
    $defaults = salamanderskins_default_theme_settings();
  
// Set combined default & saved theme settings
    variable_set($theme_setting_name, array_merge($defaults, $settings));
  
// Force theme settings refresh
    theme_get_setting('', TRUE);
  }
}


/**
* Implementation of THEMEHOOK_settings() function.
*
* @param $saved_settings
*   array An array of saved settings for this theme.
* @return
*   array A form array.
*/
function salamanderskins_settings($saved_settings) {
  global $base_url;

// Retrieve & combine default and saved theme settings
  $defaults = salamanderskins_default_theme_settings();
  $settings = array_merge($defaults, $saved_settings);


// Create theme settings form widgets using Forms API

// Development settings
 $form['tnt_container']['themedev']['fix_css_limit'] = array(
    '#type' => 'checkbox',
    '#title' => t('Fix IE stylesheet limit.'),
    '#default_value' => $settings['fix_css_limit'],
    '#description' => t('This setting groups css files so Internet Explorer can see more than 30 of them. This is useful when you cannot use aggregation (e.g., when developing or using private file downloads), especially for RTL sites. But because it degrades performance and can load files out of order, CSS aggregation (<a href="!link">Optimize CSS files</a>) is <b>strongly</b> recommended instead for any production website.', array('!link' => $base_url .'/admin/settings/performance')),
  );

  $form['tnt_container']['themedev']['devlink'] = array(
    '#type' => 'checkbox',
    '#title' => t('Developer link'),
    '#default_value' => $settings['devlink'],
  );

  $form['tnt_container']['themedev']['rebuild_registry'] = array(
    '#type' => 'checkbox',
    '#title' => t('Rebuild theme registry on every page.'),
    '#default_value' => $settings['rebuild_registry'],
    '#description' => t('During theme development, it can be very useful to continuously rebuild the theme registry. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
  );

// Return theme settings form
  return $form;
}  

?>